<?php
/**
 * Implements hook_apps_app_info().
 */
function enterprise_blog_apps_app_info() {
  return array(
    'configure form' => 'enterprise_blog_apps_app_configure_form',
    'demo content module' => 'enterprise_blog_content',
  );
}

function enterprise_blog_apps_app_configure_form() {
  $form = array();

  if (module_exists('blog')) {
    drupal_set_message('You have enabled the Core Blog module in addition to the Blog App. This can cause confusion and unintended consequences. Please disable the blog module. You can do so ' . l('here', 'admin/modules'), 'error');
  }

  $theme = variable_get('theme_default', 'bartik');

  // Fetch and sort blocks.
  require_once(drupal_get_path('module', 'block') . '/block.admin.inc');
  $blog_block_deltas = array('blog-list', 'blog-archive');
  $blocks = block_admin_display_prepare_blocks($theme);
  $blog_blocks = array();
  foreach($blocks as $block) {
    if (in_array($block['delta'], $blog_block_deltas)) {
      $blog_blocks[] = $block;
    }
  }

  $block_regions = system_region_list($theme);

  $form['blocks'] = array(
    '#type' => 'fieldset',
    '#title' => t('Blocks'),
    '#tree' => TRUE,
    '#description' => t("Place the blog blocks on your site. If they aren't on the site then they won't show up. You can also set these from the blocks admin page under Structure.")
  );

  foreach ($blog_blocks as $i => $block) {
    $key = $block['module'] . '_' . $block['delta'];
    $form['blocks'][$key]['module'] = array(
      '#type' => 'value',
      '#value' => $block['module'],
    );
    $form['blocks'][$key]['delta'] = array(
      '#type' => 'value',
      '#value' => $block['delta'],
    );
    $form['blocks'][$key]['theme'] = array(
      '#type' => 'value',
      '#value' => $theme,
    );
    $form['blocks'][$key]['weight'] = array(
      '#type' => 'value',
      '#value' => $block['weight'],
    );
    $form['blocks'][$key]['region'] = array(
      '#type' => 'select',
      '#default_value' => $block['region'] != BLOCK_REGION_NONE ? $block['region'] : NULL,
      '#empty_value' => BLOCK_REGION_NONE,
      '#title' => t('Region for @block block', array('@block' => $block['info'])),
      '#options' => $block_regions,
    );
  }
  $form['blocks']['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );

  $form['create_blog'] = array(
    '#markup' => 'Create new blog posts on the ' . l(t('Create Blog Post Page'), 'node/add/enterprise-blog', array('query' =>drupal_get_destination())) . ".",
  );

  // Use the default block admin form submit.
  $form['#submit'][] = 'block_admin_display_form_submit';

  return $form;
}
